@@ -9,7 +9,7 @@ package Time::Monotonic;
 use Exporter 'import';
 our @EXPORT_OK = qw(monotonic_time);
 
-our $VERSION = 'v0.9.7';
+our $VERSION = 'v0.9.8';
 
 require XSLoader;
 XSLoader::load('Time::Monotonic', $VERSION);
@@ -28,7 +28,7 @@ sub is_monotonic {
 
 sub new {
     my ($class, $offset) = @_;
-    my $now = monotonic_time() + ($offset // 0);
+    my $now = monotonic_time() + ($offset || 0);
     bless \$now => ref $class || $class;
 }
 
